@@ -2,7 +2,7 @@ package WebService::UrbanDictionary;
 
 # ABSTRACT: An OO interface to UrbanDictionary.com's JSON API.
 
-our $VERSION = "2.000";
+our $VERSION = "2.002";
 
 use Carp;
 use strict;
@@ -37,7 +37,7 @@ WebService::UrbanDictionary - An OO interface to UrbanDictionary.com's JSON API.
 
 =head1 VERSION
 
-version 2.000
+version 2.002
 
 =head1 SYNOPSIS
 
@@ -74,6 +74,12 @@ L<WWW::Search::UrbanDictionary>
 
 William Woodruff <william@tuffbizz.com>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Gabriel Vieira
+
+Gabriel Vieira <gabriel.vieira@gmail.com>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is Copyright (c) 2014 by William Woodruff.
